@@ -103,10 +103,10 @@ data_plot <- function(x, ...) {
 #' model <- suppressWarnings(stan_glm(
 #'   Sepal.Length ~ Petal.Width + Species + Sepal.Width,
 #'   data = iris,
-#'   chains = 2, iter = 200
+#'   chains = 2, iter = 200, refresh = 0
 #' ))
 #'
-#' result <- hdi(model, ci = c(0.5, 0.75, 0.9, 0.95))
+#' result <- bayestestR::hdi(model, ci = c(0.5, 0.75, 0.9, 0.95))
 #' data <- data_plot(result, data = model)
 #'
 #' p <- ggplot(
@@ -132,6 +132,9 @@ add_plot_attributes <- function(x) {
   if (!is.null(info$title)) {
     out[[length(out) + 1L]] <- ggplot2::labs(title = info$title)
   }
+  if (!is.null(info$subtitle)) {
+    out[[length(out) + 1L]] <- ggplot2::labs(subtitle = info$subtitle)
+  }
 
   out
 }
@@ -145,6 +148,11 @@ add_plot_attributes <- function(x) {
   obj_name <- attr(x, "object_name", exact = TRUE)
   dat <- NULL
 
+  # for simulated residuals, we save all necessary information in the object
+  if (inherits(x, "performance_simres")) {
+    return(x$fittedModel)
+  }
+
   if (!is.null(obj_name)) {
     # first try, parent frame
     dat <- tryCatch(get(obj_name, envir = parent.frame()), error = function(e) NULL)
@@ -176,7 +184,7 @@ add_plot_attributes <- function(x) {
 
 #' @keywords internal
 .dynGet <- function(x,
-                    ifnotfound = stop(gettextf("%s not found", sQuote(x)), domain = NA),
+                    ifnotfound = stop(gettextf("%s not found", sQuote(x)), domain = NA, call. = FALSE),
                     minframe = 1L,
                     inherits = FALSE) {
   x <- insight::safe_deparse(x)
