@@ -11,7 +11,9 @@
 #'
 #' @seealso See also the vignette about [`check_model()`](https://easystats.github.io/performance/articles/check_model.html).
 #'
-#' @examplesIf require("performance") && require("patchwork")
+#' @examplesIf require("patchwork")
+#' library(performance)
+#'
 #' model <- lm(qsec ~ drat + wt, data = mtcars)
 #' plot(check_model(model))
 #'
@@ -39,6 +41,7 @@ plot.see_check_model <- function(x,
   model_info <- attr(x, "model_info")
   overdisp_type <- attr(x, "overdisp_type")
   plot_type <- attr(x, "type")
+  model_class <- attr(x, "model_class")
 
   if (missing(type) && !is.null(plot_type) && plot_type %in% c("density", "discrete_dots", "discrete_interval", "discrete_both")) {
     type <- plot_type
@@ -83,6 +86,8 @@ plot.see_check_model <- function(x,
     p$PP_CHECK <- plot.see_performance_pp_check(
       x$PP_CHECK,
       style = style,
+      size_line = size_line,
+      size_point = size_point,
       type = type,
       check_model = TRUE,
       adjust_legend = TRUE,
@@ -164,18 +169,32 @@ plot.see_check_model <- function(x,
   }
 
   if ("QQ" %in% names(x) && !is.null(x$QQ) && any(c("qq", "all") %in% check)) {
-    p$QQ <- .plot_diag_qq(
-      x$QQ,
-      size_point,
-      size_line,
-      alpha_level = alpha_level,
-      detrend = detrend,
-      theme_style = style,
-      colors = colors,
-      dot_alpha_level = dot_alpha_level,
-      show_dots = TRUE, # qq-plots w/o dots makes no sense
-      model_info = model_info
-    )
+    if (inherits(x$QQ, "performance_simres")) {
+      p$QQ <- plot(
+        x$QQ,
+        size_line = size_line,
+        size_point = size_point,
+        alpha = alpha_level,
+        dot_alpha = dot_alpha_level,
+        colors = colors,
+        detrend = detrend,
+        style = style
+      )
+    } else {
+      p$QQ <- .plot_diag_qq(
+        x$QQ,
+        size_point,
+        size_line,
+        alpha_level = alpha_level,
+        detrend = detrend,
+        theme_style = style,
+        colors = colors,
+        dot_alpha_level = dot_alpha_level,
+        show_dots = TRUE, # qq-plots w/o dots makes no sense
+        model_info = model_info,
+        model_class = model_class
+      )
+    }
   }
 
   if ("NORM" %in% names(x) && !is.null(x$NORM) && any(c("normality", "all") %in% check)) {
@@ -209,9 +228,9 @@ plot.see_check_model <- function(x,
     pw <- plots(p, n_columns = n_columns)
     .safe_print_plots(pw, ...)
     invisible(pw)
-  } else {
-    return(p)
   }
+
+  p
 }
 
 
