@@ -103,7 +103,7 @@ data_plot.p_significance <- function(x,
   groups <- unique(dataplot$y)
   if (!show_intercept) {
     dataplot <- .remove_intercept(dataplot, column = "y", show_intercept)
-    groups <- unique(setdiff(groups, .intercepts()))
+    groups <- unique(setdiff(groups, .intercept_names))
   }
 
   if (length(groups) == 1) {
@@ -169,7 +169,7 @@ data_plot.p_significance <- function(x,
 #' m <<- suppressWarnings(stan_glm(Sepal.Length ~ Petal.Width * Species, data = iris, refresh = 0))
 #' result <- p_significance(m)
 #' plot(result)
-#' @importFrom ggplot2 .data
+#'
 #' @export
 plot.see_p_significance <- function(x,
                                     data = NULL,
@@ -186,12 +186,13 @@ plot.see_p_significance <- function(x,
     x <- data_plot(x, data = data, show_intercept = show_intercept)
   }
 
-  # check if we have multiple panels
-  if ((!"Effects" %in% names(x) || length(unique(x$Effects)) <= 1L) &&
-    (!"Component" %in% names(x) || length(unique(x$Component)) <= 1L)) {
+  if (.has_multiple_panels(x)) {
     n_columns <- NULL
   }
 
+  # get parameter names for filtering
+  params <- unique(x$y)
+
   # get labels
   labels <- .clean_parameter_names(x$y, grid = !is.null(n_columns))
 
@@ -216,6 +217,7 @@ plot.see_p_significance <- function(x,
     p <- p +
       .add_prior_layer_ridgeline(
         model,
+        parameter = params,
         show_intercept = show_intercept,
         priors_alpha = priors_alpha
       ) +
