@@ -4,6 +4,6 @@ test_that("`plot.see_estimate_contrasts()` works", {
 
   model <- stan_glm(Sepal.Width ~ Species, data = iris, refresh = 0)
   contrasts <- modelbased::estimate_contrasts(model, contrast = "Species")
-  means <- modelbased::estimate_means(model, at = c("Species"))
+  means <- modelbased::estimate_means(model, at = "Species")
   expect_s3_class(plot(contrasts, means), "gg")
 })
